@@ -3,7 +3,7 @@
 #
 # Author: Slaven Rezic
 #
-# Copyright (C) 2014,2015,2017,2018,2019 Slaven Rezic. All rights reserved.
+# Copyright (C) 2014,2015,2017,2018,2019,2020 Slaven Rezic. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -11,9 +11,10 @@
 # WWW:  http://www.rezic.de/eserte/
 #
 
-package Map::Metro::Plugin::Map::Berlin {
+{
+    package Map::Metro::Plugin::Map::Berlin;
 
-    our $VERSION = '2019.1215';
+    our $VERSION = '2020.1101';
 
     use Moose;
     use File::ShareDir 'dist_dir';
